==> dasu_3.02.jar: edu/northwestern/dasu/PersistentData.java <==
/**
 * Dasu Project
 *
 * File:         PersistentData.java
 * RCS:          $Id$
 * Description:  PersistentData class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 24, 2010 at 2:27:04 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.TreeMap;

import edu.northwestern.dasu.measurement.HistoricSignalHolder;
import edu.northwestern.dasu.measurement.ProbeType;
import edu.northwestern.dasu.measurement.TestType;
import edu.northwestern.dasu.timer.CronjobEntry;
import edu.northwestern.dasu.util.HashMapCache;
import edu.northwestern.dasu.util.Pair;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The PersistentData class ...
 */
public class PersistentData implements Serializable{

	private static final long serialVersionUID = 1221642255540144449L;

	private int maxLogEntries = 
	DasuConfiguration.getInstance().getMaxLogEntries();

	private Hashtable<String, CronjobEntry> cronjobSchedule = 
		new Hashtable<String, CronjobEntry>();

	private HashMapCache<Integer, Long> taskLogHistory =
	new HashMapCache<Integer, Long>(maxLogEntries);

	/*holds probe/test history for the past minute*/
	private LinkedHashMap<Pair<ProbeType, String>, Long> shortTermProbeHistory = 
		new LinkedHashMap<Pair<ProbeType, String>, Long>();
	private LinkedHashMap<Pair<TestType, String>, Long> shortTermTestHistory = 
		new LinkedHashMap<Pair<TestType, String>, Long>();
	private Hashtable<ProbeType, Integer> shortTermProbeTally = 
		new Hashtable<ProbeType, Integer>();
	private Hashtable<TestType, Integer> shortTermTestTally = 
		new Hashtable<TestType, Integer>();
	
	/*holds the hourly tally (count) of probes*/
	private Hashtable<ProbeType, Integer> hourlyProbeTally = 
		new Hashtable<ProbeType, Integer>();
	private Hashtable<TestType, Integer> hourlyTestTally = 
		new Hashtable<TestType, Integer>();

	/* holds historic data */
	private Hashtable<String, HistoricSignalHolder> historicSamplesV2 =
		new Hashtable<String, HistoricSignalHolder>();
	
	/* holds ui data */
	public Hashtable<String, String> UIValues =  new Hashtable<String, String>();
	
	private Pair<String, Long> ispInfo = new Pair<String, Long>(null, null);
	
	private HashMap<String, String> routerStaticUpnpInfo = null;
	
	/* message log */
	private LinkedHashMap<String, Long> messageLog = new LinkedHashMap<String, Long>();
	
	/* ids temporary maps for db commits*/
	private TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> dbIdMaps = 
		new TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>>();

	private TreeMap<Long, List<Object>> dbQueue = 
		new TreeMap<Long, List<Object>>();

	
	public PersistentData() {
	}
	
	public synchronized Hashtable<String, CronjobEntry> getCronjobSchedule() {
		return this.cronjobSchedule;
	}
	
	public synchronized HashMapCache<Integer, Long> getTaskLogHistory() {
		return taskLogHistory;
	}

	public synchronized LinkedHashMap<Pair<ProbeType, String>, Long> getShortTermProbeHistory() {
		return shortTermProbeHistory;
	}

	public synchronized LinkedHashMap<Pair<TestType, String>, Long> getShortTermTestHistory() {
		return shortTermTestHistory;
	}
	
	public synchronized LinkedHashMap<String, Long> getMessageLog() {
		return messageLog;
	}

	public synchronized Hashtable<ProbeType, Integer> getShortTermProbeTally() {
		return shortTermProbeTally;
	}

	public synchronized Hashtable<TestType, Integer> getShortTermTestTally() {
		return shortTermTestTally;
	}

	public synchronized Hashtable<ProbeType, Integer> getHourlyProbeTally() {
		return hourlyProbeTally;
	}

	public synchronized Hashtable<TestType, Integer> getHourlyTestTally() {
		return hourlyTestTally;
	}

	public synchronized Hashtable<String, HistoricSignalHolder> getHistoricSamplesV2() {
		return historicSamplesV2;
	}
	
	public synchronized Hashtable<String, String> getUIValues() {
		return UIValues;
	}
	
	public void setCronjobSchedule(Hashtable<String, CronjobEntry> sched) {
		this.cronjobSchedule = sched;
	}

	public void setTaskLogHistory(HashMapCache<Integer, Long> taskLogHistory) {
		this.taskLogHistory = taskLogHistory;
	}

	public void setShortTermProbeHistory(
			LinkedHashMap<Pair<ProbeType, String>, Long> shortTermProbeHistory) {
		this.shortTermProbeHistory = shortTermProbeHistory;
	}

	public void setShortTermTestHistory(
			LinkedHashMap<Pair<TestType, String>, Long> shortTermTestHistory) {
		this.shortTermTestHistory = shortTermTestHistory;
	}

	public void setShortTermProbeTally(
			Hashtable<ProbeType, Integer> shortTermProbeTally) {
		this.shortTermProbeTally = shortTermProbeTally;
	}

	public void setShortTermTestTally(
			Hashtable<TestType, Integer> shortTermTestTally) {
		this.shortTermTestTally = shortTermTestTally;
	}

	public void setHourlyProbeTally(
			Hashtable<ProbeType, Integer> hourlyProbeTally) {
		this.hourlyProbeTally = hourlyProbeTally;
	}

	public void setUIValues(Hashtable<String, String> UIValues) {
		this.UIValues = UIValues;
	}
	
	public void setHourlyTestTally(
			Hashtable<TestType, Integer> hourlyTestTally) {
		this.hourlyTestTally = hourlyTestTally;
	}
	
	public Pair<String, Long> getIspInfo() {
		return ispInfo;
	}

	public void setIspInfo(Pair<String, Long> ispInfo) {
		this.ispInfo = ispInfo;
	}
	
	public HashMap<String, String> getRouterStaticUpnpInfo(){
		return this.routerStaticUpnpInfo;
	}
	
	public void setRouterStaticUpnpInfo(HashMap<String, String> routerStaticUpnpInfo){
		this.routerStaticUpnpInfo = routerStaticUpnpInfo;
	}
		
	public void setMessageLog(LinkedHashMap<String, Long> log) {
		this.messageLog = log;
	}

	public TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> getDbIdMaps() {
		return dbIdMaps;
	}

	public void setDbIdMaps(
			TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> dbIdMaps) {
		this.dbIdMaps = dbIdMaps;
	}

	public TreeMap<Long, List<Object>> getDbQueue() {
		return dbQueue;
	}

	public void setDbQueue(TreeMap<Long, List<Object>> dbQueue) {
		this.dbQueue = dbQueue;
	}

	
}

==> dasu_4.11.jar: edu/northwestern/dasu/PersistentData.java <==
/**
 * Dasu Project
 *
 * File:         PersistentData.java
 * RCS:          $Id$
 * Description:  PersistentData class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 24, 2010 at 2:27:04 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu;

import java.io.IOException;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.TreeMap;

import edu.northwestern.cs.aqualab.Cattle.Report;
import edu.northwestern.dasu.drools.FactTemplate;
import edu.northwestern.dasu.measurement.types.TestType;
import edu.northwestern.dasu.signal.holders.HistoricSignalHolder;
import edu.northwestern.dasu.timer.CronjobEntry;
import edu.northwestern.dasu.util.HashMapCache;
import edu.northwestern.dasu.util.Pair;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The PersistentData class ...
 */
public class PersistentData implements Serializable{

	private static final long serialVersionUID = 1221642255540144454L;

	private int maxLogEntries = 
	DasuConfiguration.getInstance().getMaxLogEntries();

	private Hashtable<String, CronjobEntry> cronjobSchedule = 
		new Hashtable<String, CronjobEntry>();

	private HashMapCache<Integer, Long> taskLogHistory =
	new HashMapCache<Integer, Long>(maxLogEntries);

	/*holds probe/test history for the past minute*/
	private LinkedHashMap<Pair<TestType, String>, Long> shortTermTestHistory = 
		new LinkedHashMap<Pair<TestType, String>, Long>();
	private Hashtable<TestType, Integer> shortTermTestTally = 
		new Hashtable<TestType, Integer>();
	
	/*holds the hourly tally (count) of probes*/
	private Hashtable<TestType, Integer> hourlyTestTally = 
		new Hashtable<TestType, Integer>();

	/* holds historic data */
	private Hashtable<String, HistoricSignalHolder> historicSamplesV2 =
		new Hashtable<String, HistoricSignalHolder>();
	
	/* holds ui data */
	public Hashtable<String, String> UIValues =  new Hashtable<String, String>();
	
	private Pair<String, Long> ispInfo = new Pair<String, Long>(null, null);
	
	private HashMap<String, String> routerStaticUpnpInfo = null;
	
	/* message log */
	private LinkedHashMap<String, Long> messageLog = new LinkedHashMap<String, Long>();
	
	/* ids temporary maps for db commits*/
	private TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> dbIdMaps = 
		new TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>>();

	private TreeMap<Long, List<Object>> dbQueue = 
		new TreeMap<Long, List<Object>>();

	private Hashtable<String, Report> reports = new Hashtable<String, Report>();
	
	private Hashtable<String, byte[]> baos = new Hashtable<String, byte[]>();
	
	private HashSet<FactTemplate> reportableFacts = new HashSet<FactTemplate>();
	
	/**
	 *
	 * Holds the ids used for mapping phpReportStats
	 * dbIdMaps -> DBReporterManager, Statistics... private TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> dbIdMaps;
	 *	
	 * Holds all the facts to be reported, this is the only method called by anyone looking to report something, doesn't need to be stored on disk? yes it does
	 * reportableFacts -> Statistics... private HashSet<FactTemplate> reportableFacts
	 * 
	 * Holds all the facts to be reported once flushed from the Statistics class, for both wrangler and phpReporter (through CallbackReporter)
	 * dbQueue -> Callbackreporter, DBReporterManager... protected TreeMap<Long, List<Object>> dbQueue;
	 * 
	 * Holds the facts in the form of reports to be sent by the wrangler Reporter 
	 * reports -> WranglerReporter... protected HashMap<String, Report> reports
	 * 
	 * Holds the bytestreams to be sent by the php Reporter
	 * baos -> PhpReporter... protected HashMap<String, byte[]> baos
	 * 
	 **/
	
	public PersistentData() {
	}
	
	public synchronized Hashtable<String, CronjobEntry> getCronjobSchedule() {
		return this.cronjobSchedule;
	}
	
	public synchronized HashMapCache<Integer, Long> getTaskLogHistory() {
		return taskLogHistory;
	}

	public synchronized LinkedHashMap<Pair<TestType, String>, Long> getShortTermTestHistory() {
		return shortTermTestHistory;
	}
	
	public synchronized LinkedHashMap<String, Long> getMessageLog() {
		return messageLog;
	}

	public synchronized Hashtable<TestType, Integer> getShortTermTestTally() {
		return shortTermTestTally;
	}

	public synchronized Hashtable<TestType, Integer> getHourlyTestTally() {
		return hourlyTestTally;
	}

	public synchronized Hashtable<String, HistoricSignalHolder> getHistoricSamplesV2() {
		return historicSamplesV2;
	}
	
	public synchronized Hashtable<String, String> getUIValues() {
		return UIValues;
	}
	
	public void setCronjobSchedule(Hashtable<String, CronjobEntry> sched) {
		this.cronjobSchedule = sched;
	}

	public void setTaskLogHistory(HashMapCache<Integer, Long> taskLogHistory) {
		this.taskLogHistory = taskLogHistory;
	}

	public void setShortTermTestHistory(
			LinkedHashMap<Pair<TestType, String>, Long> shortTermTestHistory) {
		this.shortTermTestHistory = shortTermTestHistory;
	}

	public void setShortTermTestTally(
			Hashtable<TestType, Integer> shortTermTestTally) {
		this.shortTermTestTally = shortTermTestTally;
	}

	public void setUIValues(Hashtable<String, String> UIValues) {
		this.UIValues = UIValues;
	}
	
	public void setHourlyTestTally(
			Hashtable<TestType, Integer> hourlyTestTally) {
		this.hourlyTestTally = hourlyTestTally;
	}
	
	public Pair<String, Long> getIspInfo() {
		return ispInfo;
	}

	public void setIspInfo(Pair<String, Long> ispInfo) {
		this.ispInfo = ispInfo;
	}
	
	public synchronized HashMap<String, String> getRouterStaticUpnpInfo(){
		return this.routerStaticUpnpInfo;
	}
	
	public void setRouterStaticUpnpInfo(HashMap<String, String> routerStaticUpnpInfo){
		this.routerStaticUpnpInfo = routerStaticUpnpInfo;
	}
		
	public void setMessageLog(LinkedHashMap<String, Long> log) {
		this.messageLog = log;
	}

	public synchronized TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> getDbIdMaps() {
		return dbIdMaps;
	}
	
	public synchronized HashSet<FactTemplate> getReportableFacts() {
		return reportableFacts;
	}

	public void setReportableFacts (HashSet<FactTemplate> reportableFacts) {
		this.reportableFacts = reportableFacts;
	}
	
	public void setDbIdMaps(
			TreeMap<Long, Hashtable<String, Hashtable<String, Integer>>> dbIdMaps) {
		this.dbIdMaps = dbIdMaps;
	}

	public synchronized TreeMap<Long, List<Object>> getDbQueue() {
		return dbQueue;
	}

	public void setDbQueue(TreeMap<Long, List<Object>> dbQueue) {
		this.dbQueue = dbQueue;
	}

	public synchronized Hashtable<String, Report> getReports() {
		return reports;
	}

	public void setReports(Hashtable<String, Report> reports) {
		this.reports = reports;
	}
	
	public synchronized Hashtable<String, byte[]> getBaos() {
		return baos;
	}
	
	public void setBaos(Hashtable<String, byte[]> baos) {
		this.baos = baos;
	}
	
	private void writeObject(ObjectOutputStream oos)
			throws IOException {
		
		//System.out.println("writing...");
		synchronized(dbIdMaps) {
			synchronized(dbQueue) {
				synchronized(reportableFacts) {
					synchronized(shortTermTestHistory) {
						synchronized(taskLogHistory) {
							oos.defaultWriteObject();
						}
					}
				}
			}
		}
	}
	
}
